==> TudoNail-0.3.zip: TudoNail-0.3/setup.py <==
from distutils.core import setup
setup(
  name = 'TudoNail',         # How you named your package folder (MyLib)
  packages = ['TudoNail'],   # Chose the same as "name"
  version = '0.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'multischema',   # Give a short description about your library
  author = 'nhatnh236',                   # Type in your name
  author_email = 'nhatnh236@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/nhatnh236/tudo-nail-module',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/nhatnh236/tudo-nail-module/archive/v1.0.tar.gz',    # I explain this later on
  keywords = ['multischema'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'alembic','SQLAlchemy'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> TudoNail-1.1.zip: TudoNail-1.1/setup.py <==
from distutils.core import setup
setup(
  name = 'TudoNail',         # How you named your package folder (MyLib)
  packages = ['TudoNail'],   # Chose the same as "name"
  version = '1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'multischema',   # Give a short description about your library
  author = 'nhatnh236',                   # Type in your name
  author_email = 'nhatnh236@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/nhatnh236/tudo-nail-module',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/nhatnh236/tudo-nail-module/archive/v1.1.tar.gz',    # I explain this later on
  keywords = ['multischema'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'alembic'
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8'
  ],
)
